@@ -32,11 +32,11 @@ lifertable.individual <- function(ColumnAge,
   }
 
   LIFERTABLE$Lx <- Survival * (LIFERTABLE$FEMALES / n)
-  LIFERTABLE$Mx <- (LIFERTABLE$NEGG / LIFERTABLE$FEMALES) * SexRate
+  LIFERTABLE$hx <- LIFERTABLE$NEGG / LIFERTABLE$FEMALES # Nuevo 1.0.1
+  LIFERTABLE$Mx <- LIFERTABLE$hx * SexRate
   LIFERTABLE$LxMx <- LIFERTABLE$Lx * LIFERTABLE$Mx
   LIFERTABLE$xLxMx <- LIFERTABLE$AGE * LIFERTABLE$LxMx
 
-  # NUEVOS CÁLCULOS - -
   Lx1 <- c(LIFERTABLE$Lx[-1], 0)
   LIFERTABLE$gx <- Lx1 / LIFERTABLE$Lx
 
