@@ -67,14 +67,15 @@ lifertable.jackknife <- function(Female,
                              TotalEggs = FALSE)$PARAMETERS)
     })
 
-  PARAMETERS <- DJK[[1]]
+  #PARAMETERS <- DJK[[1]]
   partials <- do.call(rbind, DJK)
 
   pseudos <- lapply( partials,
                      FUN = function(x) { (n * x[1]) - ((n - 1) * x) } )
 
-  pseudos <- lapply( pseudos,
-                     FUN = function(x){ x[-1] } )
+
+  pseudos <- lapply( pseudos, FUN = function(x){ x[-1] } )
+
 
   Lifertable <- lifertable(ColumnFemale = JK$Female,
                            ColumnAge = JK$Age,
@@ -83,8 +84,21 @@ lifertable.jackknife <- function(Female,
                            Survival = JK$Survival,
                            CI = FALSE, ...)
 
-  Lifertable$CI <- lapply(pseudos, FUN = intconf )
-  class(Lifertable$CI) <- "lifertableCI"
+  Lifertable$CI <- lapply(pseudos, FUN = intconfJK )
+
+
+
+  # Nuevo
+  Lifertable$PARAMETERS$Ro <- Lifertable$CI$Ro[[2]]
+  Lifertable$PARAMETERS$Rm <- Lifertable$CI$Rm[[2]]
+  Lifertable$PARAMETERS$GT <- Lifertable$CI$GT[[2]]
+  Lifertable$PARAMETERS$DT <- Lifertable$CI$DT[[2]]
+  Lifertable$PARAMETERS$Lambda <- Lifertable$CI$Lambda[[2]]
+
+
+
+
+  class(Lifertable$CI) <- "lifertableCIJackknife"
 
   Lifertable$PSEUDOS <- pseudos
 
