@@ -7,6 +7,9 @@
 #'
 #' @inheritParams lifertable
 #'
+#' @param time A string that defines the time period over which “Age” is measured
+#'     ("days", "months", "years", etc). Default is "days".
+#'
 #' @importFrom ggplot2 aes geom_point geom_boxplot geom_line facet_wrap labs theme element_text ggsave
 #'
 #' @return Returns an object of [`class`][base::class] c("gg", "ggplot").
@@ -35,7 +38,8 @@ plotDistrOvipos <- function (ColumnFemale,
                              ColumnEggs,
                              ColumnGroups,
                              data,
-                             InitiationOfAdultStage = 0) {
+                             adultStage = 0,
+                             time = "days") {
 
   if (missing(data)) {
     Female <- ColumnFemale
@@ -47,10 +51,10 @@ plotDistrOvipos <- function (ColumnFemale,
     Eggs <- eval(substitute(ColumnEggs), data)
   }
 
-  Init <- tryCatch({ eval(substitute(InitiationOfAdultStage), data) },
-                   error = function(e) { InitiationOfAdultStage } )
+  Init <- tryCatch({ eval(substitute(adultStage), data) },
+                   error = function(e) { adultStage } )
 
-  #Age <- Age + InitiationOfAdultStage
+  #Age <- Age + adultStage
 
   if (!missing(ColumnGroups)) {
     Group <- tryCatch({ eval(substitute(ColumnGroups), data) },
@@ -67,7 +71,7 @@ plotDistrOvipos <- function (ColumnFemale,
       DT <- data.frame(Group = Init2$Group, Female = Init2$Female,
                        Age = Init2$Age+Init2$Init, Eggs = Init2$Eggs)
     } else {
-      stop("`InitiationOfAdultStage` has incorrect length")
+      stop("`adultStage` has incorrect length")
     }
 
     meansH <- stats::aggregate(Eggs ~ Age + Group, data = DT, FUN = mean, na.rm = TRUE)
@@ -78,7 +82,7 @@ plotDistrOvipos <- function (ColumnFemale,
       geom_line(data = meansH, mapping = aes(Age, Eggs)) +
       facet_wrap( ~ Group, scales = "free", ncol = 1) +
       labs(title = "DISTRIBUTION OF AGE AT OVIPOSITION",
-           x = "Age", y = "Number of eggs") +
+           x = paste0("Age (", time, ")"), y = "Number of eggs") +
       theme(plot.title = element_text(hjust = 0.5))
 
   } else {
@@ -92,7 +96,7 @@ plotDistrOvipos <- function (ColumnFemale,
       geom_boxplot(mapping = aes(group = Age, color = Age), show.legend = FALSE ) +
       geom_line(data = meansH, mapping = aes(Age, Eggs)) +
       labs(title = "DISTRIBUTION OF AGE AT OVIPOSITION",
-           x = "Age", y = "Number of eggs") +
+           x = paste0("Age (", time, ")"), y = "Number of eggs") +
       theme(plot.title = element_text(hjust = 0.5))
   }
 
